"""
This module provides pydantic schemas for JSON Web Keys.
"""
from typing import List, Optional

from pydantic import BaseModel


class JWK(BaseModel):
    """
    This Model provides a specification for the objects retrieved from JWK endpoints in OIDC
    providers. It also assists with validation and item access.
    """

    alg: str
    e: str
    kid: str
    kty: str
    n: str

    use: Optional[str]
    x5c: Optional[List[str]]
    x5t: Optional[str]

    class Config:
        extra = "allow"


class JWKs(BaseModel):
    """
    This Model provides a specification for the container object retrieved from JWK endpoints in
    OIDC providers. It also assists with validation and item access.
    """

    keys: List[JWK]



"""
This module defines a pydantic schema for the payload of a jwt.
"""

from datetime import datetime
from typing import List

from pydantic import BaseModel, Field


class TokenPayload(BaseModel):
    """
    A convenience class that can be used to access parts of a decoded jwt.
    """

    sub: str
    permissions: List[str] = Field(list())
    expire: datetime = Field(None, alias="exp")
    client_id: str = Field(None, alias="azp")

    class Config:
        extra = "allow"

    def to_dict(self):
        """
        Converts a TokenPayload to the equivalent dictionary returned by `jwt.decode()`.
        """
        return dict(
            sub=self.sub,
            permissions=self.permissions,
            exp=int(self.expire.timestamp()),
            client_id=self.client_id,
        )



"""
This module provides a pydantic schema describing Armasec's configuration parameters.
"""
from typing import Any, Dict, List, Optional, Set, Union

from pydantic import BaseModel, Field


class DomainConfig(BaseModel):
    """
    This model provides a specification for the input domains to authenticate against.
    It expects the domain indeed and the audience to refer to.
    """

    domain: str = Field(str(), description="The OIDC domain where resources are loaded.")
    audience: Optional[str] = Field(None, description="Optional designation of the token audience.")
    algorithm: str = Field(
        "RS256", description="The the algorithm to use for decoding. Defaults to RS256."
    )
    use_https: bool = Field(
        True,
        description=(
            "If falsey, use ``http`` when pulling openid config "
            "from the OIDC server instead of ``https`` (the default)."
        ),
    )
    match_keys: Dict[
        str, Union[str, List[Any], Dict[Any, Any], Set[Any], bool, int, float]
    ] = Field(
        dict(),
        description=(
            "Dictionary of key-value pair to match in the token when decoding it. It will"
            " raise 403 in case the input key-value pair cannot be found in the token."
        ),
    )



"""
This module provides a pydantic schema describing openid-configuration data.
"""
from pydantic import AnyHttpUrl, BaseModel


class OpenidConfig(BaseModel):
    """
    Provides a specification for the objects retrieved from openid_configuration endpoint of the
    OIDC providers. Only includes needed fields for supported Manager instances. Assists with
    validation and item access.
    """

    issuer: AnyHttpUrl
    jwks_uri: AnyHttpUrl

    class Config:
        extra = "allow"



import buzz
import starlette.status


class ArmasecError(buzz.Buzz):
    """
    A custom exception class used for checking conditions and handling other exceptions.
    """

    status_code = starlette.status.HTTP_400_BAD_REQUEST


class AuthenticationError(ArmasecError):
    """
    Indicates a failure to authenticate and decode jwt.
    """

    status_code = starlette.status.HTTP_401_UNAUTHORIZED


class AuthorizationError(ArmasecError):
    """
    Indicates that the provided claims don't match the claims required for a protected endpoint.
    """

    status_code = starlette.status.HTTP_403_FORBIDDEN



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['armasec', 'armasec.schemas']

package_data = \
{'': ['*']}

install_requires = \
['auto-name-enum>=2,<3',
 'fastapi>=0.68,<0.69',
 'httpx>=0,<1',
 'py-buzz>=3.1,<4.0',
 'pytest>=6,<7',
 'python-jose[cryptography]>=3.2,<4.0',
 'respx>=0,<1',
 'snick>=1.3,<2.0']

entry_points = \
{'pytest11': ['pytest_armasec = armasec.pytest_extension']}

setup_kwargs = {
    'name': 'armasec',
    'version': '0.11.2',
    'description': 'Injectable FastAPI auth via OIDC',
    'long_description': '.. image:: https://img.shields.io/github/workflow/status/omnivector-solutions/armasec/test_on_push/main?label=main-build&logo=github&style=plastic\n   :alt: main build\n.. image:: https://img.shields.io/github/issues/omnivector-solutions/armasec?label=issues&logo=github&style=plastic\n   :alt: github issues\n.. image:: https://img.shields.io/github/issues-pr/omnivector-solutions/armasec?label=pull-requests&logo=github&style=plastic\n   :alt: pull requests\n.. image:: https://img.shields.io/github/contributors/omnivector-solutions/armasec?logo=github&style=plastic\n   :alt: github contributors\n\n.. image:: https://img.shields.io/pypi/pyversions/armasec?label=python-versions&logo=python&style=plastic\n   :alt: python versions\n.. image:: https://img.shields.io/pypi/v/armasec?label=pypi-version&logo=python&style=plastic\n   :alt: pypi version\n\n.. image:: https://img.shields.io/pypi/l/armasec?style=plastic\n   :alt: license\n\n.. figure:: https://github.com/omnivector-solutions/armasec/blob/main/docs-source/_static/logo.png?raw=true\n   :alt: Logo\n   :align: center\n   :width: 80px\n\n   An Omnivector Solutions initiative\n\n=========\n Armasec\n=========\n\nAdding a security layer on top of your API can be difficult, especially when working with an OIDC\nplatform. It\'s hard enough to get your OIDC provider configured correctly. Armasec aims to take the\npain out of securing your APIs routes.\n\nArmasec is an opinionated library that attemtps to use the most obvious and commonly used workflows\nwhen working with OIDC and making configuration as simple as possible.\n\nWhen using the\n`Armasec <https://github.com/omnivector-solutions/armasec/blob/main/armasec/armasec.py>`_ helper\nclass, you only need two configuration settings to get going:\n\n#. Domain: the domain of your OIDC provider\n#. Audience: An optional setting that restricts tokens to those intended for your API.\n\nThat\'s it! Once you have those settings dialed in, you can just worry about checking the permissions\nscopes of your endpoints\n\n\nDocumentation\n=============\n\nDocumentation is hosted hosted on ``github.io`` at\n`the Armasec homepage <https://omnivector-solutions.github.io/armasec/>`_\n\n\nQuickstart\n==========\n\n#. Install ``armasec`` and ``uvicorn``:\n\n   $ pip install armasec\n\n\n#. Minimal Example (example.py)\n\n.. code-block:: python\n\n   import os\n\n   from armasec import Armasec\n   from fastapi import FastAPI, Depends\n\n\n   app = FastAPI()\n   armasec = Armasec(\n       os.environ.get("ARMASEC_DOMAIN"),\n       audience=os.environ.get("ARMASEC_AUDIENCE"),\n   )\n\n   @app.get("/stuff", dependencies=[Depends(armasec.lockdown("read:stuff"))])\n   async def check_access():\n       return dict(message="Successfully authenticated!")\n\n#. Run the app\n\n   $ uvicorn --host 0.0.0.0 example:app\n\n\nLicense\n=======\n\nDistributed under the MIT License. See `LICENSE` for more information.\n',
    'author': 'Omnivector Solutions',
    'author_email': 'info@omnivector.solutions',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/omnivector-solutions/armasec',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6.2,<4.0.0',
}


setup(**setup_kwargs)
